@@ -7,17 +7,19 @@ use LWP;
 use XML::Simple;
 use Data::Dumper;
 use vars qw($VERSION);
-$VERSION = '1.01';
+$VERSION = '1.03';
 
 1;
 
 =head1 NAME
 
-Netdot::Client::REST - Perl module for interacting with the Netdot application using the REST model
+Netdot::Client::REST - RESTful API for Netdot
 
 =head1 SYNOPSIS
 
  use Netdot::Client::REST;
+ use Data::Dumper;
+
  my $netdot = Netdot::Client::REST->new(
      server=>'http://localhost.localdomain/netdot',
      username=>'admin',
@@ -25,7 +27,9 @@ Netdot::Client::REST - Perl module for interacting with the Netdot application u
      );
 
  # Get all devices
- my $dev = $netdot->get('/Device');
+ my @devs = $netdot->get('/Device');
+
+ print Dumper(@devs);
 
  # Get Device id 1
  my $dev = $netdot->get('/Device/1');
@@ -45,13 +49,13 @@ See examples/ directory for a sample script
 =head1 DESCRIPTION
 
 Netdot::Client::REST can be used in Perl scripts that need access to the Netdot application
-database. Communication occurs over HTTP/HTTPS, thus avoiding the need to open SQL access on the
-machine running Netdot.  
+database. Communication occurs over HTTP/HTTPS, thus avoiding the need to open SQL access on the machine running Netdot.  
 
 =head1 CLASS METHODS
 =cut
 
 ############################################################################
+
 =head2 new - Constructor and login method
 
   Arguments:
@@ -65,13 +69,14 @@ machine running Netdot.
   Returns:
     Netdot::Client::REST object
   Examples:
-    my $netdot = Netot::Client::REST->new(
+    my $netdot = Netdot::Client::REST->new(
          server   =>'http://host.localdomain/netdot',
          username => 'myuser',
          password => 'mypass',
     );
 
 =cut
+
 sub new { 
     my ($proto, %argv) = @_;
     my $class = ref( $proto ) || $proto;
@@ -134,6 +139,7 @@ sub new {
 =cut
 
 ############################################################################
+
 =head2 get - Get all attributes from one or more Netdot objects
 
   Arguments:
@@ -145,7 +151,8 @@ sub new {
     referenced by the given object and records that reference the given object (both
     sides of the one-to-many relationship).  The performance impact of the given depth
     is a balance between fewer queries with large datasets and more queries with smaller
-    datasets. The default depth is 0 (only return the given object).
+    datasets. The default depth is 0 (only return the given object plus references
+    to objects directly related).
 
   Returns:
     hashref with object's attributes
@@ -167,6 +174,7 @@ sub new {
     my @mydevs = $netdot->get('Device?sysname=mydev');
  
 =cut
+
 sub get { 
     my ($self, $resource) = @_;
     croak "Missing required arguments" unless ( $resource );
@@ -182,6 +190,7 @@ sub get {
 }
 
 ############################################################################
+
 =head2 post - Update or Insert a Netdot object
 
   Arguments:
@@ -190,10 +199,11 @@ sub get {
   Returns:
     hashref with object's attributes
   Examples:
-    $netdot->post('Device/1', %data);
-    $netdot->post('Device', %data);
+    $netdot->post('Device/1', \%data);
+    $netdot->post('Device', \%data);
  
 =cut
+
 sub post { 
     my ($self, $resource, $data) = @_;
     croak "Missing required arguments" unless ( $resource && $data );
@@ -208,6 +218,7 @@ sub post {
 }
 
 ############################################################################
+
 =head2 delete - Delete a Netdot object
 
   Arguments:
@@ -218,6 +229,7 @@ sub post {
     $netdot->delete('Device/1');
  
 =cut
+
 sub delete { 
     my ($self, $resource) = @_;
     croak "Missing required arguments" unless ( $resource );
@@ -232,8 +244,6 @@ sub delete {
     }
 }
 
-=cut
-
 =head1 AUTHOR
 
 Carlos Vicente  <cvicente@cpan.org>
@@ -244,7 +254,7 @@ The Network Documentation Tool <http://netdot.uoregon.edu>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2010, Carlos Vicente <cvicente@cpan.org>. All rights reserved.
+Copyright (c) 2012, Carlos Vicente <cvicente@cpan.org>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
